==> eiffelstudio-16.05.tar: F_code/C4/cl191.c <==
/*
 * Code for class CLASS_TYPE_NAME_SYNTAX_CHECKER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "cl191.h"
#include <ctype.h>

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.default_create */
void F232_2932 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("default_create", 231, Current, 0, 0, 3061);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(1026, 0x00).id, 1026, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1022_7412(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_valid_class_type_name */
EIF_BOOLEAN F232_2933 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("is_valid_class_type_name", 231, Current, 0, 1, 3062);
	RTGC;
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(2);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(3);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(4);
	F232_2934(Current);
	RTHOOK(5);
	Result = '\0';
	if (F232_2948(Current)) {
		Result = (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 6L));
	}
	RTHOOK(6);
	RTLE;
	RTEE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_start */
void F232_2934 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_CHARACTER_32 tw1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("consume_start", 231, Current, 0, 0, 3063);
	RTGC;
	RTHOOK(1);
	tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) 'S';
	*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
	RTHOOK(2);
	F232_2952(Current);
	RTHOOK(3);
	F232_2953(Current);
	RTHOOK(4);
	F232_2935(Current);
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_type */
void F232_2935 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("consume_type", 231, Current, 0, 0, 3064);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 2L))) {
		RTHOOK(2);
		F232_2953(Current);
		RTHOOK(3);
		F232_2936(Current);
	} else {
		RTHOOK(4);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
	}
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_generics */
void F232_2936 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("consume_generics", 231, Current, 0, 0, 3065);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 3L))) {
		RTHOOK(2);
		F232_2953(Current);
		RTHOOK(3);
		F232_2935(Current);
		RTHOOK(4);
		F232_2937(Current);
	}
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_type_list */
void F232_2937 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("consume_type_list", 231, Current, 0, 0, 3066);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 4L))) {
		RTHOOK(2);
		F232_2953(Current);
	} else {
		RTHOOK(3);
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 5L))) {
			RTHOOK(4);
			F232_2953(Current);
			RTHOOK(5);
			F232_2935(Current);
			RTHOOK(6);
			F232_2937(Current);
		} else {
			RTHOOK(7);
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
		}
	}
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.current_parsed_string */
EIF_REFERENCE F232_2946 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_end_of_input */
EIF_BOOLEAN F232_2948 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("is_end_of_input", 231, Current, 0, 0, 3055);
	RTGC;
	RTHOOK(1);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_);
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R6321[Dtype(tr1)-1024])(RTCW(tr1));
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (ti4_1 > ti4_2);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_eof */
EIF_BOOLEAN F232_2951 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_CHARACTER_32 tw1;
	EIF_CHARACTER_32 tw2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("is_eof", 231, Current, 0, 0, 3058);
	RTGC;
	RTHOOK(1);
	tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
	tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\000';
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(tw1 == tw2);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_current_character */
void F232_2952 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_CHARACTER_32 tw1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("consume_current_character", 231, Current, 0, 0, 3059);
	RTGC;
	RTHOOK(1);
	if (F232_2948(Current)) {
		RTHOOK(2);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\000';
		*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
	} else {
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(Current);
		tw1 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R6285[Dtype(tr1)-1025])(RTCW(tr1), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_));
		*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
		RTHOOK(4);
		(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_))++;
	}
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_current_token */
void F232_2953 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("consume_current_token", 231, Current, 1, 0, 3060);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) != ((EIF_INTEGER_32) 7L))) {
		for (;;) {
			RTHOOK(2);
			tb1 = '\01';
			tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
			tb2 = EIF_TEST(isspace(tw1));
			if (!(EIF_BOOLEAN) !tb2) {
				tb1 = F232_2951(Current);
			}
			if (tb1) break;
			RTHOOK(3);
			F232_2952(Current);
		}
		RTHOOK(4);
		if ((EIF_BOOLEAN) !F232_2951(Current)) {
			RTHOOK(5);
			switch (*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_)) {
				case (EIF_CHARACTER_8) '[':
					RTHOOK(6);
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 3L);
					RTHOOK(7);
					F232_2952(Current);
					break;
				case (EIF_CHARACTER_8) ']':
					RTHOOK(8);
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 4L);
					RTHOOK(9);
					F232_2952(Current);
					break;
				case (EIF_CHARACTER_8) ',':
					RTHOOK(10);
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 5L);
					RTHOOK(11);
					F232_2952(Current);
					break;
				default:
					RTHOOK(12);
					tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
					tr1 = RTLNS(eif_new_type(981, 0x00).id, 981, _OBJSIZ_0_0_0_1_0_0_0_0_);
					*(EIF_CHARACTER_32 *)tr1 = tw1;
					tb2 = F980_7313(RTCW(tr1));
					if (tb2) {
						RTHOOK(13);
						*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
						RTHOOK(14);
						tr1 = RTLNS(eif_new_type(1026, 0x00).id, 1026, _OBJSIZ_1_1_0_3_0_0_0_0_);
						F1025_7523(RTCW(tr1), ((EIF_INTEGER_32) 20L));
						loc1 = (EIF_REFERENCE) tr1;
						for (;;) {
							RTHOOK(15);
							tb2 = '\01';
							if (!F232_2951(Current)) {
								tb3 = '\01';
								tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
								tr1 = RTLNS(eif_new_type(981, 0x00).id, 981, _OBJSIZ_0_0_0_1_0_0_0_0_);
								*(EIF_CHARACTER_32 *)tr1 = tw1;
								tb4 = F980_7321(RTCW(tr1));
								if (!tb4) {
									tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '_';
									tb3 = (EIF_BOOLEAN)(*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) == tw1);
								}
								tb2 = (EIF_BOOLEAN) !tb3;
							}
							if (tb2) break;
							RTHOOK(16);
							F1027_7651(RTCW(loc1), *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_));
							RTHOOK(17);
							F232_2952(Current);
						}
						RTHOOK(18);
						tr1 = RTOUCR(484,F231_2920,(Current));
						tr2 = F1027_7671(RTCW(loc1));
						tb3 = F810_6242(RTCW(tr1), tr2);
						if (tb3) {
							RTHOOK(19);
							*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
						}
					} else {
						RTHOOK(20);
						*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
					}
					break;
			}
		} else {
			RTHOOK(21);
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 6L);
		}
	}
	RTHOOK(22);
	RTLE;
	RTEE;
}

void EIF_Minit191 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C4/cl191.c <==
/*
 * Code for class CLASS_TYPE_NAME_SYNTAX_CHECKER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "cl191.h"
#include <ctype.h>

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.default_create */
void F228_2954 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1032, 0x01).id, 1032, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1024_7897(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_valid_class_type_name */
EIF_BOOLEAN F228_2955 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	F228_2956(Current);
	Result = '\0';
	if (F228_2970(Current)) {
		Result = (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 6L));
	}
	RTLE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_start */
void F228_2956 (EIF_REFERENCE Current)
{
	GTCX
	EIF_CHARACTER_32 tw1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) 'S';
	*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
	F228_2974(Current);
	F228_2975(Current);
	F228_2957(Current);
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_type */
void F228_2957 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 2L))) {
		F228_2975(Current);
		F228_2958(Current);
	} else {
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_generics */
void F228_2958 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 3L))) {
		F228_2975(Current);
		F228_2957(Current);
		F228_2959(Current);
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_type_list */
void F228_2959 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 4L))) {
		F228_2975(Current);
	} else {
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 5L))) {
			F228_2975(Current);
			F228_2957(Current);
			F228_2959(Current);
		} else {
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
		}
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_end_of_input */
EIF_BOOLEAN F228_2970 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_);
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R6723[Dtype(RTCW(tr1))-1027])(tr1);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (ti4_1 > ti4_2);
	RTLE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_eof */
EIF_BOOLEAN F228_2973 (EIF_REFERENCE Current)
{
	GTCX
	EIF_CHARACTER_32 tw1;
	EIF_CHARACTER_32 tw2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
	tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\000';
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(tw1 == tw2);
	RTLE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_current_character */
void F228_2974 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_CHARACTER_32 tw1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if (F228_2970(Current)) {
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\000';
		*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
	} else {
		tr1 = *(EIF_REFERENCE *)(Current);
		tw1 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R6687[Dtype(RTCW(tr1))-1027])(tr1, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_));
		*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
		(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_))++;
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_current_token */
void F228_2975 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) != ((EIF_INTEGER_32) 7L))) {
		for (;;) {
			tb1 = '\01';
			tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
			tb2 = EIF_TEST(isspace(tw1));
			if (!(EIF_BOOLEAN) !tb2) {
				tb1 = F228_2973(Current);
			}
			if (tb1) break;
			F228_2974(Current);
		}
		if ((EIF_BOOLEAN) !F228_2973(Current)) {
			switch (*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_)) {
				case (EIF_CHARACTER_8) '[':
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 3L);
					F228_2974(Current);
					break;
				case (EIF_CHARACTER_8) ']':
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 4L);
					F228_2974(Current);
					break;
				case (EIF_CHARACTER_8) ',':
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 5L);
					F228_2974(Current);
					break;
				default:
					tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
					tr1 = RTLNS(eif_new_type(980, 0x00).id, 980, _OBJSIZ_0_0_0_1_0_0_0_0_);
					*(EIF_CHARACTER_32 *)tr1 = tw1;
					tb2 = F979_7751(RTCW(tr1));
					if (tb2) {
						*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
						loc1 = RTLNS(eif_new_type(1032, 0x01).id, 1032, _OBJSIZ_1_1_0_3_0_0_0_0_);
						F1031_8190(RTCW(loc1), ((EIF_INTEGER_32) 20L));
						for (;;) {
							tb2 = '\01';
							if (!F228_2973(Current)) {
								tb3 = '\01';
								tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
								tr1 = RTLNS(eif_new_type(980, 0x00).id, 980, _OBJSIZ_0_0_0_1_0_0_0_0_);
								*(EIF_CHARACTER_32 *)tr1 = tw1;
								tb4 = F979_7759(RTCW(tr1));
								if (!tb4) {
									tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '_';
									tb3 = (EIF_BOOLEAN)(*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) == tw1);
								}
								tb2 = (EIF_BOOLEAN) !tb3;
							}
							if (tb2) break;
							F1033_8317(RTCW(loc1), *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_));
							F228_2974(Current);
						}
						tr1 = RTOSCF(2942,F227_2942, (Current));
						tr2 = F1033_8337(RTCW(loc1));
						tb3 = F806_6496(RTCW(tr1), tr2);
						if (tb3) {
							*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
						}
					} else {
						*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
					}
					break;
			}
		} else {
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 6L);
		}
	}
	RTLE;
}

void EIF_Minit191 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
